tcrdist_rs documentation
=========================

tcrdist_rs is a package for fast, parallelized CPU TCRdist, hamming, and Levenshtein distance routines, with the latter two being Python bindings to the triple_accel Rust package. 
All code is freely available at `<https://github.com/zacmon/tcrdist_rs>`_.

Welcome to tcrdist_rs's documentation!
======================================

.. toctree::
   :maxdepth: 1
   :caption: User Guide

   install

.. toctree::
   :maxdepth: 2
   :caption: Tutorials

.. toctree::
   :maxdepth: 0 
   :caption: API Docmentation

   api

.. toctree::
   :maxdepth: 2
   :caption: Developer Documentation

   developer
   todo

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
